@@ -28,12 +28,8 @@
 #include <QDate>
 #include <QPixmap>
 
-namespace EventViews
-{
-
-namespace CalendarDecoration
-{
-
+namespace EventViews {
+namespace CalendarDecoration {
 /**
   @class Element
 
@@ -118,10 +114,9 @@ class EVENTVIEWS_EXPORT StoredElement : public Element
 public:
     explicit StoredElement(const QString &id);
     StoredElement(const QString &id, const QString &shortText);
-    StoredElement(const QString &id, const QString &shortText,
-                  const QString &longText);
-    StoredElement(const QString &id, const QString &shortText,
-                  const QString &longText, const QString &extensiveText);
+    StoredElement(const QString &id, const QString &shortText, const QString &longText);
+    StoredElement(const QString &id, const QString &shortText, const QString &longText,
+                  const QString &extensiveText);
     StoredElement(const QString &id, const QPixmap &pixmap);
 
     virtual void setShortText(const QString &t);
@@ -162,6 +157,7 @@ public:
     {
         return 2;
     }
+
     static QString serviceType()
     {
         return QStringLiteral("Calendar/Decoration");
@@ -265,9 +261,7 @@ class EVENTVIEWS_EXPORT DecorationFactory : public CalendarSupport::PluginFactor
 public:
     Decoration *createPluginFactory() override = 0;
 };
-
 }
-
 }
 
 #endif
